from distutils.core import setup

setup(
    name='jhhalchemy',
    version='0.2',
    packages=['jhhalchemy'],
    url='https://github.com/JawboneHealth/jhhalchemy',
    license='Apache',
    author='Ray Courtney',
    author_email='ray@jawbone.com',
    description='SQLAlchemy base model and CRUD methods for Jawbone Health'
)
